@@ -630,7 +630,7 @@ impl<'a> PdfType3Font<'a> {
                                 }
                                 dlog!("{} = {} ({:?})", code, name, unicode);
                                 if let Some(ref unicode_map) = unicode_map {
-                                    dlog!("{} {}", code, unicode_map.get(&(code as u32)));
+                                    dlog!("{} {:?}", code, unicode_map.get(&(code as u32)));
                                 }
                                 code += 1;
                             }
@@ -638,8 +638,12 @@ impl<'a> PdfType3Font<'a> {
                         }
                     }
                 }
-                let name = pdf_to_utf8(encoding.get(b"Type").unwrap().as_name().unwrap());
-                dlog!("name: {}", name);
+                let name_encoded = encoding.get(b"Type");
+                if let Ok(Object::Name(name)) = name_encoded {
+                    dlog!("name: {}", pdf_to_utf8(name));
+                } else {
+                    dlog!("name not found");
+                }
 
                 encoding_table = Some(table);
             }
@@ -1146,12 +1150,14 @@ fn show_text(gs: &mut GraphicsState, s: &[u8],
         //dlog!("w: {}", font.widths[&(*c as i64)]);
         let w0 = font.get_width(c) / 1000.;
 
+        let mut spacing = ts.character_spacing;
         // "Word spacing is applied to every occurrence of the single-byte character code 32 in a
         //  string when using a simple font or a composite font that defines code 32 as a
         //  single-byte code. It does not apply to occurrences of the byte value 32 in
         //  multiple-byte codes."
         let is_space = c == 32 && length == 1;
-        let spacing = if is_space { ts.word_spacing } else { ts.character_spacing };
+        if is_space { spacing += ts.word_spacing }
+
         output.output_character(&trm, w0, spacing, ts.font_size, &font.decode_char(c))?;
         let tj = 0.;
         let ty = 0.;
@@ -1487,7 +1493,7 @@ impl<'a> Processor<'a> {
                     gs.ts.font = Some(font);
 
                     gs.ts.font_size = as_num(&operation.operands[1]);
-                    dlog!("font {} size: {} {:?}", name, gs.ts.font_size, operation);
+                    dlog!("font {} size: {} {:?}", pdf_to_utf8(name), gs.ts.font_size, operation);
                 }
                 "Ts" => {
                     gs.ts.rise = as_num(&operation.operands[0]);
@@ -1970,7 +1976,7 @@ pub fn print_metadata(doc: &Document) {
     if let Some(ref info) = get_info(&doc) {
         for (k, v) in *info {
             match v {
-                &Object::String(ref s, StringFormat::Literal) => { dlog!("{}: {}", k, pdf_to_utf8(s)); }
+                &Object::String(ref s, StringFormat::Literal) => { dlog!("{}: {}", pdf_to_utf8(k), pdf_to_utf8(s)); }
                 _ => {}
             }
         }
